@@ -11,14 +11,6 @@ pub trait Storage: Send + Sync {
 
     /// Finish write transaction, size is new size of underlying storage.
     fn commit(&mut self, size: u64);
-
-    /// Read multiple ranges. List is (file offset, data offset, data size).
-    fn read_multiple(&self, list: &[(u64, usize, usize)], data: &mut [u8]) {
-        for (addr, off, size) in list {
-            let data = &mut data[*off..off + *size];
-            self.read(*addr, data);
-        }
-    }
 }
 
 use crate::Mutex;
